@@ -71,7 +71,7 @@ use Digest::MD5;
 #inherits Apache::Session
 #link Lemonldap::NG::Common::Apache::Session::SOAP protected globalStorage
 
-our $VERSION = '1.4.5';
+our $VERSION = '1.4.7';
 
 use base qw(Lemonldap::NG::Common::CGI Exporter);
 our @ISA;
@@ -1129,7 +1129,7 @@ sub get_module {
 
     if ( $type =~ /auth/i ) {
         if ( defined $self->{_multi}->{stack}->[0] ) {
-            return $self->{_multi}->{stack}->[0]->[0]->{n};
+            return $self->{_multi}->{stack}->[0]->[0]->{s};
         }
         if ( defined $self->{_choice}->{modules} ) {
             return $self->{_choice}->{modules}->[0]->{n};
@@ -1141,7 +1141,7 @@ sub get_module {
 
     if ( $type =~ /user/i ) {
         if ( defined $self->{_multi}->{stack}->[1] ) {
-            return $self->{_multi}->{stack}->[1]->[0]->{n};
+            return $self->{_multi}->{stack}->[1]->[0]->{s};
         }
         if ( defined $self->{_choice}->{modules} ) {
             return $self->{_choice}->{modules}->[1]->{n};
@@ -1289,6 +1289,7 @@ sub _dump {
     my $variable = shift;
 
     require Data::Dumper;
+    $Data::Dumper::Indent = 0;
     $self->lmLog( "Dump: " . Data::Dumper::Dumper($variable), 'debug' );
 
     return;
@@ -2007,8 +2008,11 @@ sub setMacros {
 sub setLocalGroups {
     my $self = shift;
     foreach ( sort keys %{ $self->{groups} } ) {
-        $self->{sessionInfo}->{groups} .= $self->{multiValuesSeparator} . $_
-          if ( $self->safe->reval( $self->{groups}->{$_} ) );
+        if ( $self->safe->reval( $self->{groups}->{$_} ) ) {
+            $self->{sessionInfo}->{groups} .=
+              $self->{multiValuesSeparator} . $_;
+            $self->{sessionInfo}->{hGroups}->{$_}->{name} = $_;
+        }
     }
 
     # Clear values separator at the beginning
@@ -2373,6 +2377,7 @@ sub store {
             $displayValue = '****';
         }
         $self->lmLog( "Store $displayValue in session key $k", 'debug' );
+        $self->_dump($displayValue) if ref($displayValue);
         $infos->{$k} = $self->{sessionInfo}->{$k};
     }
     $session->update($infos);
@@ -2561,7 +2566,8 @@ sub autoRedirect {
 
     # Redirection should be made if
     #  - urldc defined
-    if ( $self->{urldc} ) {
+    #  - lmError parameter is not defined
+    if ( $self->{urldc} and !$self->param("lmError") ) {
 
         # Cross-domain mechanism
         if (    $self->{cda}
@@ -2836,7 +2842,7 @@ used to redirect the user after authentication.
 
 Controls if a previous session is always available. If true, it call the sub
 C<existingSession> with two parameters: id and a scalar tied on Apache::Session
-module choosed to store sessions. See bellow
+module choosed to store sessions. See below
 
 =head3 existingSession
 
